==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/NodeDaemonEndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NodeDaemonEndpointsFluent<A extends io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildKubeletEndpoint instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.DaemonEndpoint getKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.DaemonEndpoint buildKubeletEndpoint();
  public A withKubeletEndpoint(io.fabric8.kubernetes.api.model.DaemonEndpoint kubeletEndpoint);
  public java.lang.Boolean hasKubeletEndpoint();
  public A withNewKubeletEndpoint(java.lang.Integer port);
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpointLike(io.fabric8.kubernetes.api.model.DaemonEndpoint item);
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpointLike(io.fabric8.kubernetes.api.model.DaemonEndpoint item);
  public interface KubeletEndpointNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.DaemonEndpointFluent<io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<N>>{
    public N and();
    public N endKubeletEndpoint();
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/NodeDaemonEndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NodeDaemonEndpointsFluent<A extends io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildKubeletEndpoint instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.DaemonEndpoint getKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.DaemonEndpoint buildKubeletEndpoint();
  public A withKubeletEndpoint(io.fabric8.kubernetes.api.model.DaemonEndpoint kubeletEndpoint);
  public java.lang.Boolean hasKubeletEndpoint();
  public A withNewKubeletEndpoint(java.lang.Integer port);
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpointLike(io.fabric8.kubernetes.api.model.DaemonEndpoint item);
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpoint();
  public io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpointLike(io.fabric8.kubernetes.api.model.DaemonEndpoint item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface KubeletEndpointNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.DaemonEndpointFluent<io.fabric8.kubernetes.api.model.NodeDaemonEndpointsFluent.KubeletEndpointNested<N>>{
    public N and();
    public N endKubeletEndpoint();
    
  }
  
}
